@@ -3,7 +3,7 @@ import traceback
 import shutil
 from sys import platform, stdout, stderr, exc_info
 
-VERSION = "0.5.2"
+VERSION = "0.5.4"
 
 XDEBUG = 0
 DEBUG = 10
@@ -37,6 +37,21 @@ def _should_print(scope, level):
     return level >= _threshold(scope)
 
 
+_left_align = "  "
+_right_align = ":  "
+
+
+def set_align(left, right):
+    """Set alignment for scope, tag, and message
+    If `left`, `right` are strings, then they will we placed left or right of
+    the scope or tag, respectively.
+    If they are numeric, this specifies the width of the field instead.
+    """
+    global _left_align, _right_align
+    _left_align = left
+    _right_align = right
+
+
 class Signale:
 
     def __init__(self, opts={"scope": None, "underlined": False, "ansi": None}):
@@ -47,7 +62,7 @@ class Signale:
             self.custom_loggers_conf = opts["custom"]
             for conf in self.custom_loggers_conf:
                 func = lambda text="", prefix="", suffix="", level=conf["level"]: self.log(
-                    text, prefix, suffix, conf, level)
+                    text=text, prefix=prefix, suffix=suffix, level=level, conf=conf)
                 setattr(self, conf["name"], func)
 
         try:
@@ -182,10 +197,15 @@ class Signale:
         return f"{reversed}{text}{reset}"
 
     def logger_label(self, color, icon, label):
+        label_len = len(label)
         if self.underlined == True:
             label = self.underline(label)
         label = self.bold(label)
-        label = self.coloured(color, "{} {}".format(icon, label))
+        label = self.coloured(color, icon + " " + label)
+        if type(_right_align) == int:
+            label += ":" + " " * (_right_align - label_len)
+        else:
+            label += _right_align
         return label
 
     def logger(self, text="", prefix="", suffix=""):
@@ -194,13 +214,19 @@ class Signale:
         """
         if self.scope != None:
             if isinstance(self.scope, list):
-                leader = "  " + "".join(map(lambda x: f"[{x}]", self.scope))
+                leader = "".join(map(lambda x: f"[{x}]", self.scope))
             else:
-                leader = f"  [{self.scope}]"
+                leader = f"[{self.scope}]"
         else:
-            leader = " "
+            leader = ""
         if prefix != "":
-            leader += f" [{prefix}] {self.figures['pointerSmall']}"
+            if leader != "":
+                leader += " "
+            leader += f"[{prefix}] {self.figures['pointerSmall']}"
+        if type(_left_align) == int:
+            leader = " " * (_left_align - len(leader)) + leader
+        else:
+            leader = _left_align + leader
         leader = self.bright_gray(leader)
         if suffix != "":
             trailer = self.gray(f"   -- {suffix}")
@@ -208,12 +234,12 @@ class Signale:
             trailer = ""
         return f"{leader} {text}{trailer}"
 
-    def log(self, text="", prefix="", suffix="", conf={}, level=INFO):
+    def log(self, text="", prefix="", suffix="", level=INFO, conf={}):
         if not self._any_threshold(level):
             return
-        text = "{}:  {}".format(self.logger_label(
-            conf["color"], conf["badge"], "{}".format(conf["label"])), text)
-        message = self.logger(text, prefix, suffix)
+        text = self.logger_label(
+            conf["color"], conf["badge"], conf["label"]) + str(text)
+        message = self.logger(text, str(prefix), str(suffix))
         self.println(message)
 
     def simple(self, text="", prefix="", suffix="", level=INFO):
@@ -222,30 +248,22 @@ class Signale:
         self.println(self.logger(text, prefix, suffix))
 
     def success(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        tick = self.figures["tick"]
-        text = "{}:  {}".format(self.logger_label(
-            "green", tick, "Success"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "green",
+                 "badge": self.figures["tick"],
+                 "label": "Success"})
 
     def start(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["play"]
-        text = "{}:  {}".format(
-            self.logger_label("green", icon, "Start"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "green",
+                 "badge": self.figures["play"],
+                 "label": "Start"})
 
     def error(self, text="", prefix="", suffix="", level=ERROR):
-        if not self._any_threshold(level):
-            return
-        cross = self.figures["cross"]
-        text = "{}:  {}".format(self.logger_label("red", cross, "Error"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "red",
+                 "badge": self.figures["cross"],
+                 "label": "Error"})
 
     def exception(self, text="", prefix="", suffix="", level=ERROR):
         if not self._any_threshold(level):
@@ -253,108 +271,78 @@ class Signale:
         e = exc_info()
         suffix += e[0].__name__
         if len(str(e[1])) > 0:
-            suffix += e[1]
+            suffix += str(e[1])
         suffix += '\n    Traceback (most recent call last):\n  ' + \
             ''.join(traceback.format_tb(e[2])).rstrip().replace('\n', '\n  ')
         self.error(text=text, prefix=prefix, suffix=suffix)
 
     def warning(self, text="", prefix="", suffix="", level=WARNING):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["warning"]
-        text = "{}:  {}".format(self.logger_label(
-            "yellow", icon, "Warning"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "yellow",
+                 "badge": self.figures["warning"],
+                 "label": "Warning"})
 
     warn = warning
 
     def watch(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["ellipsis"]
-        text = "{}:  {}".format(self.logger_label(
-            "yellow", icon, "Watching"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "yellow",
+                 "badge": self.figures["ellipsis"],
+                 "label": "Watching"})
 
     def stop(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["squareSmallFilled"]
-        text = "{}:  {}".format(self.logger_label("red", icon, "Stop"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "red",
+                 "badge": self.figures["squareSmallFilled"],
+                 "label": "Stop"})
 
     def important(self, text="", prefix="", suffix="", level=WARNING):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["star"]
-        text = "{}:  {}".format(self.logger_label(
-            "yellow", icon, "Important"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "yellow",
+                 "badge": self.figures["star"],
+                 "label": "Important"})
 
     def pending(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["radioOff"]
-        text = "{}:  {}".format(self.logger_label(
-            "purple", icon, "Pending"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "purple",
+                 "badge": self.figures["radioOff"],
+                 "label": "Pending"})
 
     def debug(self, text="", prefix="", suffix="", level=DEBUG):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["squareSmallFilled"]
-        text = "{}:  {}".format(self.logger_label(
-            "dark blue", icon, "Debug"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "dark blue",
+                 "badge": self.figures["squareSmallFilled"],
+                 "label": "Debug"})
 
     def xdebug(self, text="", prefix="", suffix="", level=XDEBUG):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["eyes"]
-        text = "{}:  {}".format(self.logger_label(
-            "dark blue", icon, "XDebug"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "dark blue",
+                 "badge": self.figures["eyes"],
+                 "label": "XDebug"})
 
     def info(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["info"]
-        text = "{}:  {}".format(self.logger_label("cyan", icon, "Info"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "cyan",
+                 "badge": self.figures["info"],
+                 "label": "Info"})
 
     def pause(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["pause"]
-        text = "{}:  {}".format(self.logger_label(
-            "yellow", icon, "Pause"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "yellow",
+                 "badge": self.figures["pause"],
+                 "label": "Pause"})
 
     def complete(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["radioOn"]
-        text = "{}:  {}".format(self.logger_label(
-            "blue", icon, "Complete"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "blue",
+                 "badge": self.figures["radioOn"],
+                 "label": "Complete"})
 
     def like(self, text="", prefix="", suffix="", level=INFO):
-        if not self._any_threshold(level):
-            return
-        icon = self.figures["heart"]
-        text = "{}:  {}".format(self.logger_label("pink", icon, "Like"), text)
-        message = self.logger(text=text, prefix=prefix, suffix=suffix)
-        self.println(message)
+        self.log(text, prefix, suffix, level, {
+                 "color": "pink",
+                 "badge": self.figures["heart"],
+                 "label": "Like"})
 
     def center(self, text="", prefix="", suffix=""):
         # `shutil.get_terminal_size()` actually queries stdout, not stderr;
@@ -490,8 +478,8 @@ if __name__ == "__main__":
     logger.println("\n")
 
     logger = Signale({"scope": "custom"})
-    logger.success("Started Successfully", prefix="Debugger")
-    logger.warning("`a` function is deprecated", suffix="main.py")
+    logger.success(b"Started Successfully", prefix=50)
+    logger.warning("`a` function is deprecated", suffix=20)
     logger.complete("Run Complete")
 
     logger = Signale({
@@ -565,3 +553,11 @@ if __name__ == "__main__":
 
     set_threshold("inner", XDEBUG)
     logger2.xdebug("Now Visible")
+
+    logger.println("\n")
+    logger.center("Alignment")
+    set_align(23, 8)
+    logger.warning("Example")
+    logger.debug("Narrow")
+    logger2.xdebug("Wide")
+    logger.info("Cool output", prefix="Wow")
